pub struct MemoryBlock {
pub address: usize,
pub size: usize,
pub allocated: bool,
pub move_priority: u32,
pub age: Duration,
pub access_frequency: f32,
pub last_access: Instant,
pub device_id: Option<usize>,
}Expand description
Memory block descriptor for defragmentation
Fields
address: usizeMemory address (pointer as usize for safety)
size: usizeSize in bytes
allocated: boolWhether the block is allocated or free
move_priority: u32Priority for moving (lower = higher priority to move)
age: DurationAge of the block (for generational strategies)
access_frequency: f32Access frequency (for hot/cold classification)
last_access: InstantLast access time
device_id: Option<usize>Associated device (for cross-device scenarios)
Implementations
Sourceimpl MemoryBlock
impl MemoryBlock
Sourcepub fn new(address: usize, size: usize, allocated: bool) -> Self
pub fn new(address: usize, size: usize, allocated: bool) -> Self
Create a new memory block descriptor
Sourcepub fn is_adjacent_to(&self, other: &MemoryBlock) -> bool
pub fn is_adjacent_to(&self, other: &MemoryBlock) -> bool
Check if this block is adjacent to another block
Sourcepub fn can_merge_with(&self, other: &MemoryBlock) -> bool
pub fn can_merge_with(&self, other: &MemoryBlock) -> bool
Check if this block can be merged with another block
Sourcepub fn record_access(&mut self)
pub fn record_access(&mut self)
Update access statistics